@@ -1,5 +1,6 @@
+use std::env;
 use std::ops::{Deref, DerefMut};
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use std::process::{self, Command};
 
 use anyhow::{Context, Result};
@@ -25,6 +26,14 @@ pub struct Build {
 }
 
 impl Build {
+    /// Create a new build from manifest path
+    #[allow(clippy::field_reassign_with_default)]
+    pub fn new(manifest_path: Option<PathBuf>) -> Self {
+        let mut build = Self::default();
+        build.manifest_path = manifest_path;
+        build
+    }
+
     /// Execute `cargo build` command with zig as the linker
     pub fn execute(&self) -> Result<()> {
         let mut build = self.build_command("build")?;
@@ -195,6 +204,17 @@ impl Build {
                         build.env("WINAPI_NO_BUNDLED_LIBRARIES", "1");
                     }
 
+                    if raw_target.contains("apple-darwin") {
+                        if let Some(sdkroot) = env::var_os("SDKROOT") {
+                            if !sdkroot.is_empty()
+                                && env::var_os("PKG_CONFIG_SYSROOT_DIR").is_none()
+                            {
+                                // Set PKG_CONFIG_SYSROOT_DIR for pkg-config crate
+                                build.env("PKG_CONFIG_SYSROOT_DIR", sdkroot);
+                            }
+                        }
+                    }
+
                     // Enable unstable `target-applies-to-host` option automatically for nightly Rust
                     // when target is the same as host but may have specified glibc version
                     if host_target == raw_target
